@@ -2,10 +2,7 @@ import time
 from ..Scheduler import IntervalTask
 from ..dbserver.base import Base, ENGINE_DICT, mysql
 
-
 # from config.config import db_config
-
-
 def dump_table(table, sql):
     if sql.is_busy():
         return
@@ -15,18 +12,19 @@ def dump_table(table, sql):
     return result
 
 class data_manager(object):
-    min_keep_connection = 10
     keep_cycle = 10
 
     def __init__(self, db_config):
         self.t_data = db_config
+        self.min_keep_connection = db_config['min_keep_connection'] if 'min_keep_connection' in db_config else 1
         if 'engine' not in self.t_data or self.t_data['engine'] not in ENGINE_DICT:
             self.t_data['engine'] = mysql
 
         self.sql_pool = {}
         print('creating DB connection pool...')
-        self.new()
-        # print('connect done!')
+        for i in range(0,self.min_keep_connection):
+            self.new()
+        print('connect done!')
         IntervalTask(data_manager.keep_cycle, self.keep_connect)
 
         self.mem_cache = {}
@@ -41,16 +39,17 @@ class data_manager(object):
 
     def keep_connect(self):
         can_update_sql = []
+        count = 0
         for sql in self.sql_pool.values():
-            if int(time.time()) - sql.get_last_connect_time() > 30:
-                print(id(sql),'超时了')
-                can_update_sql.append(sql)
-        # count = 0
-        # kill_connect = []
-        # for sql in can_update_sql:
-        #     if sql.is_busy() == False:
-        #         kill_connect.append(id(sql))
-        #         count += 1
+            if int(time.time()) - sql.last_execute_time > 30:
+                count += 1
+                if count > self.min_keep_connection:
+                    sql.become_free()
+                    can_update_sql.append(id(sql))
+                else:
+                    sql.become_busy()
+                    sql.keep_connect()
+                    sql.become_free()
         self.kill_unused_connection(can_update_sql)
         return
 
@@ -58,7 +57,7 @@ class data_manager(object):
         count = 0
         for sql_id in kill_connect:
             if sql_id in self.sql_pool:
-                if self.sql_pool[sql_id].is_busy() is False:
+                if self.sql_pool[sql_id].is_busy() == False:
                     self.sql_pool.pop(sql_id)
                     count += 1
         print('计划清理',len(kill_connect),'个空闲连接，实际清理',count,'个')
@@ -81,12 +80,12 @@ class data_manager(object):
             if sql.is_busy() is False:
                 sql.become_busy()
                 return sql
-        print('数据库连接池全忙状态，创建新的数据库链接')
+        # print('数据库连接池全忙状态，创建新的数据库链接')
         sql = self.create_new_sql()
         sql.become_busy()
         self.add_new_sql(sql)
-        # print('创建完毕')
-        # dbg_db('数据库连接池全忙状态，创建新的数据库链接', '新连接id:', id(sql))
+        # print('创建完毕新连接id:', id(sql))
+        # print('数据库连接池全忙状态，创建新的数据库链接', '新连接id:', id(sql))
         return sql
 
     def add_new_sql(self, sql):
@@ -108,7 +107,7 @@ class data_manager(object):
     def create(self, table, colums, table_comment = '',show_sql=False):
         sql = self.find_free_sql()
         # sql.become_busy()
-        print('执行这次sql请求的链接是', id(sql))
+        # print('执行这次sql请求的链接是', id(sql))
         result = sql.create(table, colums, table_comment,show_sql)
         sql.become_free()
         return result
@@ -126,8 +125,6 @@ class data_manager(object):
     def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False,from_cache = False):
         sql = self.find_free_sql()
         table = self.get_table_name(table)
-        # sql.become_busy()
-        # print('执行这次sql请求的链接是', id(sql))
         if from_cache == True:
             query = sql.find_info(table, conditions, or_cond, fields, None, order, None)
             query += " limit 1"
@@ -135,7 +132,6 @@ class data_manager(object):
             if res is not None:
                 sql.become_free()
                 return res
-
         result = sql.find(table, conditions, or_cond, fields, order, show_sql)
         if result is None:
             return
@@ -191,8 +187,8 @@ class data_manager(object):
         # print(sql)
         sql = self.find_free_sql()
         # sql.become_busy()
-        print('执行这次sql请求的链接是', id(sql))
-        result = sql.query_one(sql_query, show_sql)
+        # print('执行这次sql请求的链接是', id(sql))
+        result = sql.query(sql_query, show_sql)
         sql.become_free()
         return result
 
